@@ -46,7 +46,7 @@
 #include <sys/types.h>
 #include <sys/time.h>    /* timeval, gettimeofday() */
 #include <assert.h>
-#include "ansi.h"        /* architecture-specific */
+#include "sysdep.h"      /* system-dependent */
 
 static char rcsid[] = "$Id: multimer.c,v 1.2 1995/02/15 10:03:01 hgs Exp $";
 
@@ -65,6 +65,7 @@ static TQE *timerQ = (TQE *)0;
 /* queue of free Timer Queue Elements */
 static TQE *freeTQEQ = (TQE *)0;
 
+#ifndef timeradd
 void timeradd(struct timeval *a, struct timeval *b, 
   struct timeval *sum)
 {
@@ -77,7 +78,7 @@ void timeradd(struct timeval *a, struct timeval *b,
     sum->tv_sec = a->tv_sec + b->tv_sec;
   }
 } /* timeradd */
-
+#endif
 
 /*
 * Return 1 if a < b, 0 otherwise.
