@@ -10,9 +10,7 @@ Copyright 1993 by AT&T Bell Laboratories; all rights reserved
 #include <stdio.h>     /*DEBUG, fprintf() */
 #include <stdlib.h>    /* malloc() */
 #include <unistd.h>    /* select() */
-#if !defined(sun4) && !defined(hp) && !defined(nextstep)
-#include <sys/select.h>  /* select() */
-#endif
+#include "sysdep.h"
 #include "notify.h"
 #include "multimer.h"
 #include "ansi.h"
@@ -228,3 +226,24 @@ Notify_func_signal notify_set_signal_func(Notify_client client,
   signal(sig, sig_handler);
   return old_func;
 } /* notify_set_signal_func */
+
+
+/*
+ * Sets the value of fd_sets Rreadfds, Writefds, Exceptfds.
+ */
+void notify_set_socket(int sock, int flag)
+{
+  switch (flag) {
+  case 0:
+    FD_SET(sock, &Readfds);
+    break;
+  case 1:
+    FD_SET(sock, &Writefds);
+    break;
+  case 2:
+    FD_SET(sock, &Exceptfds);
+    break;
+  default:
+    break;
+  }
+} /* notify_set_socket */
