@@ -29,7 +29,7 @@ int RD_header(FILE *in, struct sockaddr_in *sin, int verbose)
 
     in.s_addr = hdr.source;
     tm = localtime(&hdr.start.tv_sec);
-    strftime(line, sizeof(line), "%D %T", tm);
+    strftime(line, sizeof(line), "%C", tm);
     printf("Start:  %s\n", line);
     printf("Source: %s (%d)\n", inet_ntoa(in), hdr.port);
   }
