@@ -23,8 +23,7 @@
 *  with suitably chosen file names. Each such file will be
 *  individually playable. (Gaps?)
 *
-* Copyright (c) 1995-1997 by H. Schulzrinne (GMD Fokus, Columbia U.)
-* $Id$
+* Copyright (c) 1995-1998 by H. Schulzrinne (Columbia U.)
 */
 
 #include <sys/types.h>
@@ -46,6 +45,7 @@
 #include "vat.h"
 #include "rtpdump.h"
 #include "ansi.h"
+#include "sysdep.h"
 #define VERSION "1.0"
 
 typedef u_int32 member_t;
@@ -261,7 +261,9 @@ static int parse_data(char *buf, int len)
     "v=%d p=%d x=%d cc=%d m=%d pt=%d (%s,%d,%d) seq=%u ts=%lu ssrc=0x%lx\n",
       r->version, r->p, r->x, r->cc, r->m, 
       r->pt, pt_map[r->pt].enc, pt_map[r->pt].ch, pt_map[r->pt].rate,
-      ntohs(r->seq), ntohl(r->ts), ntohl(r->ssrc));
+      ntohs(r->seq), 
+      (unsigned long)ntohl(r->ts), 
+      (unsigned long)ntohl(r->ssrc));
     for (i = 0; i < r->cc; i++) {
       printf("csrc[%d] = %0x ", i, r->csrc[i]);
     }
@@ -284,12 +286,12 @@ static void parse_short(struct timeval now, char *buf, int len)
     vat_hdr_t *v = (vat_hdr_t *)buf;
     printf("%ld.%06ld %lu\n",
       (v->flags ? -now.tv_sec : now.tv_sec), now.tv_usec,
-      ntohl(v->ts));
+      (unsigned long)ntohl(v->ts));
   }
   else if (r->version == 2) {
     printf("%ld.%06ld %lu %u\n",
       (r->m ? -now.tv_sec : now.tv_sec), now.tv_usec,
-      ntohl(r->ts), ntohs(r->seq));
+      (unsigned long)ntohl(r->ts), ntohs(r->seq));
   }
   else {
     printf("RTP version wrong (%d).\n", r->version);
@@ -388,40 +390,41 @@ static int parse_control(char *buf, int len)
       switch (r->common.pt) {
       case RTCP_SR:
         printf(" (SR ssrc=0x%lx p=%d count=%d len=%d\n", 
-          ntohl(r->r.rr.ssrc), r->common.p, r->common.count,
-	       ntohs(r->common.length));
+          (unsigned long)ntohl(r->r.rr.ssrc),
+          r->common.p, r->common.count,
+	      ntohs(r->common.length));
         printf("ntp=%lu.%lu ts=%lu psent=%lu osent=%lu\n",
-          ntohl(r->r.sr.ntp_sec),
-          ntohl(r->r.sr.ntp_frac),
-          ntohl(r->r.sr.rtp_ts),
-          ntohl(r->r.sr.psent),
-        ntohl(r->r.sr.osent));
+          (unsigned long)ntohl(r->r.sr.ntp_sec),
+          (unsigned long)ntohl(r->r.sr.ntp_frac),
+          (unsigned long)ntohl(r->r.sr.rtp_ts),
+          (unsigned long)ntohl(r->r.sr.psent),
+          (unsigned long)ntohl(r->r.sr.osent));
         for (i = 0; i < r->common.count; i++) {
           printf("  (ssrc=%0lx fraction=%g lost=%lu last_seq=%lu jit=%lu lsr=%lu dlsr=%lu)\n",
-           ntohl(r->r.sr.rr[i].ssrc),
+           (unsigned long)ntohl(r->r.sr.rr[i].ssrc),
            r->r.sr.rr[i].fraction / 256.,
-           ntohl(r->r.sr.rr[i].lost), /* XXX I'm pretty sure this is wrong */
-           ntohl(r->r.sr.rr[i].last_seq),
-           ntohl(r->r.sr.rr[i].jitter),
-           ntohl(r->r.sr.rr[i].lsr),
-           ntohl(r->r.sr.rr[i].dlsr));
+           (unsigned long)ntohl(r->r.sr.rr[i].lost), /* XXX I'm pretty sure this is wrong */
+           (unsigned long)ntohl(r->r.sr.rr[i].last_seq),
+           (unsigned long)ntohl(r->r.sr.rr[i].jitter),
+           (unsigned long)ntohl(r->r.sr.rr[i].lsr),
+           (unsigned long)ntohl(r->r.sr.rr[i].dlsr));
         }
         printf(" )\n"); 
         break;
 
       case RTCP_RR:
         printf(" (RR ssrc=0x%lx p=%d count=%d len=%d\n", 
-          ntohl(r->r.rr.ssrc), r->common.p, r->common.count,
-	       ntohs(r->common.length));
+          (unsigned long)ntohl(r->r.rr.ssrc), r->common.p, r->common.count,
+	      ntohs(r->common.length));
         for (i = 0; i < r->common.count; i++) {
           printf("(ssrc=%0lx fraction=%g lost=%lu last_seq=%lu jit=%lu lsr=%lu dlsr=%lu)\n",
-           ntohl(r->r.rr.rr[i].ssrc),
-           r->r.rr.rr[i].fraction / 256.,
-           ntohl(r->r.rr.rr[i].lost),
-           ntohl(r->r.rr.rr[i].last_seq),
-           ntohl(r->r.rr.rr[i].jitter),
-           ntohl(r->r.rr.rr[i].lsr),
-           ntohl(r->r.rr.rr[i].dlsr));
+            (unsigned long)ntohl(r->r.rr.rr[i].ssrc),
+            r->r.rr.rr[i].fraction / 256.,
+            (unsigned long)ntohl(r->r.rr.rr[i].lost),
+            (unsigned long)ntohl(r->r.rr.rr[i].last_seq),
+            (unsigned long)ntohl(r->r.rr.rr[i].jitter),
+            (unsigned long)ntohl(r->r.rr.rr[i].lsr),
+            (unsigned long)ntohl(r->r.rr.rr[i].dlsr));
         }
         printf(" )\n"); 
         break;
@@ -434,7 +437,8 @@ static int parse_control(char *buf, int len)
           int remaining = (ntohs(r->common.length) << 2) -
 	    (buf - (char *)&r->r.sdes);
 
-          printf("  (src=0x%lx ", ntohl(((struct rtcp_sdes *)buf)->src));
+          printf("  (src=0x%lx ", 
+            (unsigned long)ntohl(((struct rtcp_sdes *)buf)->src));
           if (remaining > 0) {
             buf = rtp_read_sdes(buf, 
               (ntohs(r->common.length) << 2) - (buf - (char *)&r->r.sdes));
@@ -453,7 +457,8 @@ static int parse_control(char *buf, int len)
         printf(" (BYE p=%d count=%d len=%d\n", 
           r->common.p, r->common.count, ntohs(r->common.length));
         for (i = 0; i < r->common.count; i++) {
-          printf("ssrc[%d]=%0lx ", i, ntohl(r->r.bye.src[i]));
+          printf("ssrc[%d]=%0lx ", i, 
+            (unsigned long)ntohl(r->r.bye.src[i]));
         }
         if (ntohs(r->common.length) > r->common.count) {
           buf = (char *)&r->r.bye.src[r->common.count];
@@ -464,7 +469,8 @@ static int parse_control(char *buf, int len)
 
       /* invalid type */
       default:
-        printf("(? pt=%d src=0x%lx)\n", r->common.pt, ntohl(r->r.sdes.src));
+        printf("(? pt=%d src=0x%lx)\n", r->common.pt, 
+          (unsigned long)ntohl(r->r.sdes.src));
       break;
       }
       r = (rtcp_t *)((u_int32 *)r + ntohs(r->common.length) + 1);
@@ -579,6 +585,7 @@ int main(int argc, char *argv[])
   int nfds = 0;
   extern double tdbl(struct timeval *);
 
+  startupSocket();
   while ((c = getopt(argc, argv, "b:F:f:t:x:")) != EOF) {
     switch(c) {
     /* output format */
