@@ -12,7 +12,7 @@
 * Currently does not correct SR/RR absolute (NTP) timestamps,
 * but should. Receiver reports are fairly meaningless.
 *
-* (c) 1994-1998 Henning Schulzrinne
+* (c) 1994-1998 Henning Schulzrinne (Columbia University); all rights reserved
 */
 
 #include <stdio.h>
@@ -33,6 +33,7 @@
 #include "rtpdump.h"     /* RD_packet_t */
 #include "multimer.h"    /* timer_set() */
 #include "ansi.h"
+#include "sysdep.h"
 
 #define READAHEAD 16 /* must be power of 2 */
 
@@ -106,8 +107,8 @@ static double tdbl(struct timeval *a)
 static void play_transmit(int b)
 {
   if (b >= 0 && buffer[b].p.hdr.length) {
-    if (write(sock[buffer[b].p.hdr.plen == 0],
-        buffer[b].p.data, buffer[b].p.hdr.length) < 0) {
+    if (send(sock[buffer[b].p.hdr.plen == 0],
+        buffer[b].p.data, buffer[b].p.hdr.length, 0) < 0) {
       perror("write");
     } 
 
@@ -157,8 +158,8 @@ static Notify_value play_handler(Notify_client client)
     if (buffer[b].p.hdr.plen) {
       r = (rtp_hdr_t *)buffer[b].p.data;
       printf(" ssrc=%8lx %cts=%9lu seq=%5u",
-        ntohl(r->ssrc), r->m ? '*' : ' ',
-        ntohl(r->ts), ntohs(r->seq));
+        (unsigned long)ntohl(r->ssrc), r->m ? '*' : ' ',
+        (unsigned long)ntohl(r->ts), ntohs(r->seq));
     }
     printf("\n");
   }
@@ -201,7 +202,7 @@ static Notify_value play_handler(Notify_client client)
     seq = ntohs(r->seq);
     pt  = r->pt;
     m   = r->m;
-    sprintf(ssrc, "%lx", ntohl(r->ssrc));
+    sprintf(ssrc, "%lx", (unsigned long)ntohl(r->ssrc));
 
     /* find hash entry */
     item.key  = ssrc;
@@ -287,6 +288,9 @@ int main(int argc, char *argv[])
   extern int optind;
   extern int hpt(char *h, struct sockaddr *sa, unsigned char *ttl);
 
+  /* For NT, we need to start the socket; dummy function otherwise */
+  startupSocket();
+
   /* parse command line arguments */
   while ((c = getopt(argc, argv, "b:e:f:p:Tv")) != EOF) {
     switch(c) {
@@ -345,6 +349,15 @@ int main(int argc, char *argv[])
         exit(1);
       }
 
+      /*
+	   * We have to set the socket array when we use 'select' in NT,
+	   * otherwise the 'select' function in NT will consider all the
+	   * three fd_sets are NULL and return an error.  Error code
+	   * WSAEINVAL means The timeout value is not valid, or all three
+	   * descriptor parameters were NULL but the timeout value is valid.
+	   * After setting Writefds, the program runs ok.
+       */
+      notify_set_socket(sock[i], 1);
       if (IN_CLASSD(ntohl(sin.sin_addr.s_addr)) && 
           (setsockopt(sock[i], IPPROTO_IP, IP_MULTICAST_TTL, &ttl,
                    sizeof(ttl)) < 0)) {
