@@ -13,7 +13,7 @@
 *   long as the sampling rate doesn't change).
 *
 * Author: Henning Schulzrinne
-* GMD Fokus, Berlin
+* Columbia University
 *
 *
 * Additionally, the translator can translate VAT packets into RTP packets. 
@@ -64,6 +64,7 @@
 #include "notify.h"
 #include "multimer.h"
 #include "vat.h"
+#include "sysdep.h"
 
 #define PAD(x,n) (((n) - ((x) & (n-1))) & (n-1))
 #define MAX_HOST 10
@@ -72,7 +73,7 @@ extern int gettimeofday();
 
 static int debug = 0;
 static int hostc = 0;
-static multi_sock[3] = {0,0,0};
+static int multi_sock[3] = {0,0,0};
 static struct {
   int sock;
   struct sockaddr_in sin;
@@ -293,12 +294,11 @@ static Notify_value socket_handler(Notify_client client, int sock)
       rtp_hdr_send.cc      = 0;
       rtp_hdr_send.ts      = vat_hdr->ts;
 
-
-#ifdef Linux 
+#if defined(Linux) || defined(WIN32)
       /* 
-       * Stupid little Linux does not support sendmsg 
-       * use copying instead; contributed by
-       * Lutz Grueneberg <gruen@rvs.uni-hannover.de>.
+	   * Stupid little Linux and stupid big Win32 does not support
+	   * sendmsg(), thus, use copying instead; contributed by Lutz
+	   * Grueneberg <gruen@rvs.uni-hannover.de>.
        */
       {
         unsigned char mbuf[10000];
@@ -327,7 +327,7 @@ static Notify_value socket_handler(Notify_client client, int sock)
         if (side[i][proto].sock != sock) {
           msg.msg_name = (caddr_t ) &side[i][proto].sin;
           msg.msg_namelen = sizeof(side[i][proto].sin);
-#if defined(__FreeBSD__) /* Or presumably other BSD 4.4 systems */
+#if defined(__FreeBSD__) || defined(__linux__) /* Or presumably other BSD 4.4 systems */
 	  msg.msg_control = 0;
 	  msg.msg_controllen = 0;
 #else
@@ -339,8 +339,8 @@ static Notify_value socket_handler(Notify_client client, int sock)
             perror("sendmsg RTCP");
           }
        }
+#endif /* Linux || WIN32 */
     }
-#endif /* Linux */
     else if (((struct CtrlMsgHdr *)packet)->type == 1) /* vat ID messages */{
       rtcp_t *rtcp_msg;
       struct sdes_msg *ctl_msg;
@@ -430,6 +430,8 @@ int main(int argc, char *argv[])
 
   extern struct in_addr host2ip(char *);
 
+  /* Set up socket. */
+  startupSocket();
   while ((c = getopt(argc, argv, "d?h")) != EOF) {
     switch(c) {
     case 'd':
@@ -500,6 +502,7 @@ int main(int argc, char *argv[])
         side[i][j].sin.sin_port = htons(ntohs(host[i].sin.sin_port) + j);
       }
       else {
+        side[i][j].sin.sin_family = AF_INET;
         side[i][j].sin.sin_addr.s_addr = INADDR_ANY;
         side[i][j].sin.sin_port = 0;
       }
